load_hosts

Function load_hosts 

pub fn load_hosts() -> Result<Vec<Host>>
Loads manually-added hosts from ~/.config/omnyssh/hosts.toml.

Returns an empty Vec if the file does not exist yet.

Errors

Returns an error if the file exists but cannot be read or parsed.