Module discovery

Module discovery 

Service discovery orchestrator.

Runs a Quick Scan to detect services on remote servers.

Architecture:

  • Quick Scan runs once per connection, discovers which services exist
  • All operations are async and use the existing SSH session
  • Results are sent via CoreEvent to the main loop

Functions

quick_scan
Performs a Quick Scan on the given SSH session.