pub struct ServiceRegistry { /* private fields */ }Expand description
Service registry that manages all available providers.
Implementations
Sourceimpl ServiceRegistry
impl ServiceRegistry
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new registry with all built-in providers. Only 5 core services are supported: Docker, Nginx, PostgreSQL, Redis, Node.js.
Sourcepub fn detect_services(&self, probe_output: &ProbeOutput) -> Vec<ServiceKind>
pub fn detect_services(&self, probe_output: &ProbeOutput) -> Vec<ServiceKind>
Detect which services are present based on probe output.
Returns a list of service kinds that were detected.
Sourcepub fn get_provider(&self, kind: &ServiceKind) -> Option<&dyn ServiceProvider>
pub fn get_provider(&self, kind: &ServiceKind) -> Option<&dyn ServiceProvider>
Get a provider by service kind.