Cross-platform utility helpers.
Constants
- LOG_
RETENTION_ DAYS - Rolling log files older than this many days are pruned at startup.
Functions
- app_
config_ dir - Returns the application config directory.
- app_
config_ path - Returns the path to the main application config file.
- cleanup_
old_ logs - Removes rolling log files in
log_dirolder thanmax_age_days. - hosts_
config_ path - Returns the path to the hosts config file.
- snippets_
config_ path - Returns the path to the snippets config file.
- ssh_
config_ path - Returns the path to the user’s SSH config file.