Probe script generation and output parsing for service discovery.
The Quick Scan probe is a single bash script that collects maximum
information in one SSH invocation. Output is delimited by
section markers (===OMNYSSH:SECTION===) for easy parsing.
Structs
- Probe
Output - Parsed output from the probe script, organized by section.
Functions
- generate_
quick_ scan_ script - Generates the Quick Scan probe bash script.