SFTP file manager operations.
Provides SftpManager — a persistent background task that owns an SSH+SFTP
session and processes SftpCommand messages sent from the UI thread.
All operations are non-blocking from the UI perspective.
Progress is reported via CoreEvent::FileTransferProgress.
Structs
- File
Entry - Metadata for a single file or directory in a file panel.
- Sftp
Manager - Manages a persistent SSH+SFTP background task.
Enums
- Sftp
Command - Commands processed by the
SftpManagerbackground task.
Functions
- list_
local_ dir - Lists the entries of a local directory, sorted dirs-first then alphabetically.
- preview_
local_ file - Reads up to 4 096 bytes from a local file and returns them as a UTF-8 string.