Module platform

Module platform 

Cross-platform utility helpers.

Constants

LOG_RETENTION_DAYS
Rolling log files older than this many days are pruned at startup.

Functions

app_config_dir
Returns the application config directory.
app_config_path
Returns the path to the main application config file.
cleanup_old_logs
Removes rolling log files in log_dir older than max_age_days.
hosts_config_path
Returns the path to the hosts config file.
snippets_config_path
Returns the path to the snippets config file.
ssh_config_path
Returns the path to the user’s SSH config file.